@@ -10,11 +10,11 @@ import numpy as np
 
 class utilities:
 
-    def __init__(self,type=None):
+    def __init__(self):
         self.base_url = "https://api.greentecq.com/v2/paper/"
         self.headers = {"Content-type": "application/x-www-form-urlencoded",
                         "Accept": "text/plain"}
-        self.type = type
+        self.type = 2
 
     def get_expiry_kite(self):
         try:
@@ -202,10 +202,13 @@ class utilities:
                 else:
                     data = {
                         'strategy_name': args["strategy_name"],
+                          'type': execution_type,
                     }
+                print(data)
                 response = requests.post(
                     self.base_url+"execution", headers=self.headers, data=data)
                 response_json = (response.json())
+                print(response_json)
                 return int(response_json['daily_execution_id'])
         except Exception as e:
             print(e)
